@@ -21,6 +21,7 @@ import sys
 import os
 import socket
 from pathlib import Path
+import psutil
 import resource
 
 os.chdir('{{ working_directory }}')
@@ -51,7 +52,11 @@ if __name__ == '__main__':
 
     job_started = datetime.datetime.now()
 
+    psutil_process = psutil.Process()
+    psutil_info = psutil_process.as_dict()
+
     print('Running on: %s' % (socket.gethostname(), ))
+    print(f'Running on CPUs: {psutil_info["cpu_affinity"]}')
     print('Now running %s' % (job_item, ))
     print('Parameters: %s' % (job_item.args, ))
     print('Keyword Parameters: %s' % (job_item.kwargs, ))
@@ -63,10 +68,17 @@ if __name__ == '__main__':
     print(f'##########\nJob stopped at {job_stopped}')
     print(f'Execution took {job_stopped - job_started}')
 
+    initial_cpu_time = sum(psutil_info['cpu_times'])
+    psutil_info = psutil_process.as_dict()
+    final_cpu_time = sum(psutil_info['cpu_times'])
+
+    avg_amount_of_cpus_used = (final_cpu_time - initial_cpu_time) / (job_stopped - job_started).seconds  # noqa
+
     mem_used = resource.getrusage(resource.RUSAGE_SELF).ru_maxrss / 1024 / 1024
 
     mem_toomuch = 100 * (requested_ram - mem_used) / mem_used
 
+    print(f'Your job used an average of {avg_amount_of_cpus_used:.2f} CPUs')
     print('Your job asked for %.2fGB of RAM' % (requested_ram, ))
     print('Your job used a maximum of %.2fGB of RAM' % (mem_used, ))
     print('You overestimated you memory usage by %.2f%%.' % (mem_toomuch, ))
