@@ -1,6 +1,6 @@
 #!/bin/bash
-{% set log_dir = jobs_dir + "/log" %}
-#SBATCH --nodes={{ request_cpus }}
+{% set log_dir = jobs_dir / "log" %}
+#SBATCH --cpus-per-task={{ request_cpus }}
 #SBATCH --mem={{ required_mem }}
 #SBATCH --array=1-{{ n_jobs }}
 #SBATCH --time={{ request_time }}
