@@ -20,8 +20,9 @@ import gzip
 import importlib
 import inspect
 import json
-import os
 import sys
+from abc import ABC
+
 import six
 from copy import deepcopy
 import hashlib
@@ -113,8 +114,7 @@ class JobItem(object):
     def _init_from_class(self, job_class, *args, **kwargs):
         self.job_module = inspect.getmodule(job_class).__name__
         if self.job_module == '__main__':
-            (path, f_name) = os.path.split(sys.argv[0])
-            self.job_module = os.path.splitext(f_name)[0]
+            self.job_module = Path(sys.argv[0]).name.stem
 
         self.job_class = job_class.__name__
 
@@ -148,7 +148,7 @@ class JobItem(object):
         return '.'.join((self.job_module, self.job_class))
 
 
-class AutomaticFilenameJob(Job):
+class AutomaticFilenameJob(Job, ABC):
     """
     Abstract class for Jobs providing automatic filename generation.
 
