@@ -22,11 +22,9 @@ import humanfriendly
 import six
 import sys
 import os
-import os.path
 import plus_slurm.job
 import subprocess
 import logging
-import glob
 import jinja2
 import uuid
 import numpy
@@ -39,11 +37,6 @@ from pathlib import Path
 
 from plus_slurm.job import JobItem
 
-if sys.version_info >= (3, 6):
-    import pathlib
-else:
-    import pathlib2 as pathlib
-
 
 class JobCluster(object):
     """
@@ -73,12 +66,6 @@ class JobCluster(object):
         respective files are put directly
         under jobs_dir. In this case, jobs_dir must either be empty or not
         exist at all to avoid any side effects.
-    owner ::class:`str`, optional
-        Username the job should run under. If you submit your jobs from one of
-        the bombers, you do not need to set this.
-        If you have set up your local machine to submit jobs and your local
-        username is different from your username
-        on the cluster, set owner to that username.
     python_bin ::class:`str`, optional
         The path to the python interpreter that should run the jobs. If you do
         not set it, it gets chosen automatically.
@@ -88,32 +75,24 @@ class JobCluster(object):
         the default one at /mnt/obob/obob_mne will be used.
     working_directory ::class:`str`, optional
         The working directory when the jobs run.
-    singularity_image ::class:`str`, optional
-        Set this to a singularity image to have the jobs execute in it.
-        Can be a link to a local file or to some online
-        repository.
     """
 
-    _default_python_env = '/mnt/obob/obob_mne/bin/python'
     _slurm_submit = '/usr/bin/sbatch'
     _runner_template = 'runner.py'
     _submit_template = 'submit.sh'
 
     def __init__(self, required_ram='2G', request_cpus=1, jobs_dir='jobs',
                  request_time=10,
-                 inc_jobsdir=True, owner=None,
-                 python_bin=None, working_directory=None,
-                 singularity_image=None):
+                 inc_jobsdir=True,
+                 python_bin=None, working_directory=None):
         self.required_ram = required_ram
         self.request_time = request_time
         self.request_cpus = request_cpus
         self.jobs_dir = jobs_dir
         self.inc_jobsdir = inc_jobsdir
-        self.owner = owner
         self.python_bin = python_bin
         self.working_directory = working_directory
         self._output_folder = None
-        self._singularity_image = singularity_image
 
         self._jobs = list()
 
@@ -166,48 +145,6 @@ class JobCluster(object):
 
                 self.add_job(job, *new_args, **new_kwargs)
 
-    def old_run_local(self):
-        """
-        Runs the added jobs locally.
-
-        """
-
-        self._remove_notrunning_jobs()
-        self._prepare_jobs_directory()
-        self._generate_runner_file()
-        submit_fname = self._generate_submit_file()
-
-        submit_dict = dict()
-        queue_glob = None
-        with open(submit_fname, 'rt') as submit_file:
-            for line in submit_file:
-                if ' = ' in line:
-                    (key, val) = line.split(' = ')
-                    submit_dict[key.strip()] = val.strip()
-                elif line.startswith('queue'):
-                    queue_glob = line.rsplit(' ', 1)[1]
-
-        for idx, cur_file in enumerate(sorted(glob.glob(queue_glob))):
-            with (
-                open(os.path.join(
-                    self._output_folder, 'log', 'out.%d' % (idx,)
-                ), 'wt') as out,
-                open(os.path.join(
-                    self._output_folder, 'log', 'err.%d' % (idx,)
-                ), 'wt') as err
-            ):
-                this_args = submit_dict['arguments'].replace(
-                    '$(filename)',
-                    os.path.abspath(cur_file)
-                )[2:-1].split(' ')
-
-                subprocess.call(
-                    [submit_dict['executable'],  this_args[0], this_args[1]],
-                    cwd=self.working_directory,
-                    stderr=err,
-                    stdout=out
-                )
-
     def run_local(self):
         """
         Runs the added jobs locally.
@@ -223,12 +160,9 @@ class JobCluster(object):
                 sorted(Path(self.output_folder, 'slurm').glob('*.json.gzip'))
         ):
             with (
-                open(os.path.join(
-                    self._output_folder, 'log', 'out.%d' % (idx,)
+                open(Path(
+                    self._output_folder, 'log', 'out_%d.log' % (idx + 1,)
                 ), 'wt') as out,
-                open(os.path.join(
-                    self._output_folder, 'log', 'err.%d' % (idx,)
-                ), 'wt') as err
             ):
 
                 env = os.environ
@@ -236,9 +170,9 @@ class JobCluster(object):
                 env['SLURM_ARRAY_JOB_ID'] = '0'
 
                 subprocess.run(
-                    [self.executable, self.arguments],
+                    [self.executable] + str(self.arguments).split(' '),
                     cwd=self.working_directory,
-                    stderr=err,
+                    stderr=subprocess.STDOUT,
                     stdout=out,
                     env=env
                 )
@@ -298,7 +232,7 @@ class JobCluster(object):
         template = self._jinja_env.get_template(self._submit_template)
 
         submit_rendered = template.render(self._jinja_context)
-        submit_fname = os.path.join(self.output_folder, 'slurm', 'submit.sh')
+        submit_fname = Path(self.output_folder, 'slurm', 'submit.sh')
         with open(submit_fname, 'wt') as submit_file:
             submit_file.write(submit_rendered)
 
@@ -314,54 +248,46 @@ class JobCluster(object):
     def _prepare_jobs_directory(self):
         final_jobs_dir = None
         if self.inc_jobsdir:
-            pathlib.Path(self.jobs_dir).mkdir(exist_ok=True)
+            Path(self.jobs_dir).mkdir(exist_ok=True)
 
             jobs_idx = 1
-            while os.path.exists(
-                    os.path.join(self.jobs_dir, '%03d' % (jobs_idx, ))
-            ):
+            while Path(self.jobs_dir, '%03d' % (jobs_idx, )).exists():
                 jobs_idx = jobs_idx + 1
 
-            final_jobs_dir = os.path.join(self.jobs_dir, '%03d' % (jobs_idx, ))
+            final_jobs_dir = Path(self.jobs_dir, '%03d' % (jobs_idx, ))
         else:
             final_jobs_dir = self.jobs_dir
-            if os.path.exists(final_jobs_dir):
+            if final_jobs_dir.exists():
                 raise ValueError('The jobs folder already exists. '
                                  'Please choose another one')
 
-        pathlib.Path(final_jobs_dir).mkdir(exist_ok=True)
+        Path(final_jobs_dir).mkdir(exist_ok=True)
 
-        json_folder = os.path.join(final_jobs_dir, 'slurm')
-        pathlib.Path(json_folder).mkdir(exist_ok=True)
-        log_folder = os.path.join(final_jobs_dir, 'log')
-        pathlib.Path(log_folder).mkdir(exist_ok=True)
+        json_folder = Path(final_jobs_dir, 'slurm')
+        Path(json_folder).mkdir(exist_ok=True)
+        log_folder = Path(final_jobs_dir, 'log')
+        Path(log_folder).mkdir(exist_ok=True)
 
         idx = 1
         for cur_job in self._jobs:
             cur_job.to_json(
-                os.path.join(json_folder, 'job%03d.json.gzip' % (idx, ))
+                Path(json_folder, 'job%03d.json.gzip' % (idx, ))
             )
             idx = idx + 1
 
-        self._output_folder = os.path.abspath(final_jobs_dir)
+        self._output_folder = final_jobs_dir.resolve()
 
         shutil.copytree(
-            os.path.split(
-                inspect.getsourcefile(inspect.getmodule(JobItem)))[0],
-            os.path.join(json_folder, 'plus_slurm')
+            Path(
+                inspect.getsourcefile(inspect.getmodule(JobItem))).parent,
+            Path(json_folder, 'plus_slurm')
         )
 
         return final_jobs_dir
 
     @property
     def owner(self):
-        return self._owner
-
-    @owner.setter
-    def owner(self, owner):
-        if not owner:
-            owner = getpass.getuser()
-        self._owner = owner
+        return getpass.getuser()
 
     @property
     def required_ram(self):
@@ -387,7 +313,7 @@ class JobCluster(object):
     def python_bin(self, python_bin):
         if not python_bin:
             python_bin = sys.executable
-        if not os.path.isfile(python_bin):
+        if not Path(python_bin).is_file():
             raise ValueError('The python interpreter does not exist.')
 
         if 'Python' not in str(
@@ -399,31 +325,17 @@ class JobCluster(object):
 
         self._python_bin = python_bin
 
-    @property
-    def singularity_command(self):
-        return '/usr/bin/singularity'
-
-    @property
-    def singularity_arguments(self):
-        return f'exec -S /home/{self.owner} -B /var/lib/condor -B /mnt --no-home --writable-tmpfs {self._singularity_image} {self.python_bin} {self.runner_filename}'  # noqa
-
     @property
     def executable(self):
-        if self._singularity_image is not None:
-            return self.singularity_command
-        else:
-            return self.python_bin
+        return self.python_bin
 
     @property
     def arguments(self):
-        if self._singularity_image is not None:
-            return self.singularity_arguments
-        else:
-            return self.runner_filename
+        return self.runner_filename
 
     @property
     def python_home(self):
-        return os.path.dirname(os.path.dirname(self.python_bin))
+        return Path(self.python_bin).parent.parent
 
     @property
     def working_directory(self):
@@ -434,7 +346,7 @@ class JobCluster(object):
         if not working_directory:
             working_directory = os.getcwd()
 
-        if not os.path.isdir(working_directory):
+        if not Path(working_directory).is_dir():
             raise ValueError('working_directory is not a valid directory.')
 
         self._working_directory = working_directory
@@ -449,7 +361,66 @@ class JobCluster(object):
 
     @property
     def runner_filename(self):
-        return os.path.join(self.output_folder, 'slurm', 'runner.py')
+        return Path(self.output_folder, 'slurm', 'runner.py')
+
+
+class SingularityJobCluster(JobCluster):
+    """
+    If you use this class instead of :class:`JobCluster`, the jobs will
+    run in a Singularity Container.
+
+    You need to supply the same parameters as when instantiating
+    :class:`JobCluster`. Additionally, you need to at least set the
+    Singularity Image you want to use.
+
+    Parameters
+    ----------
+    singularity_image ::class:`str`
+        Set this to a singularity image to have the jobs execute in it.
+        Can be a link to a local file or to some online
+        repository.
+    mounts : :class:`tuple`, :class:`list`, optional
+        What to mount in the container.
+    mount_slurm_folders : :class:`bool`
+        If `true`, mount `/etc/slurm` and `/var/run/munge` so you can
+        issue slurm commands from within the job.
+    """
+
+    _slurm_folders = ('/etc/slurm', '/var/run/munge')
+
+    def __init__(self, *args, singularity_image=None,
+                 mounts=('/mnt', ),
+                 mount_slurm_folders=True, **kwargs):
+        super().__init__(*args, **kwargs)
+        if singularity_image is None:
+            raise RuntimeError('You must specify a Singularity Image')
+
+        self._singularity_image = singularity_image
+        self._mounts = list(mounts)
+        if mount_slurm_folders:
+            for mnt in self._slurm_folders:
+                if mnt not in self._mounts:
+                    self._mounts.append(mnt)
+
+    @property
+    def singularity_command(self):
+        return '/usr/bin/singularity'
+
+    @property
+    def singularity_arguments(self):
+        cmd_list = ['exec', '--writable-tmpfs']
+        for mnt in self._mounts:
+            cmd_list.append(f'-B {mnt}')
+
+        return ' '.join(cmd_list)
+
+    @property
+    def executable(self):
+        return self.singularity_command
+
+    @property
+    def arguments(self):
+        return f'{self.singularity_arguments} {self._singularity_image} {self.python_bin} {self.runner_filename}'  # noqa
 
 
 class PermuteArgument(object):
